import { Component, Input, OnInit } from '@angular/core';
import { LegendPosition, NgxChartsModule } from '@swimlane/ngx-charts';

@Component({
  selector: 'app-line-chart',
  templateUrl: './line-chart.component.html',
  styleUrls: ['./line-chart.component.scss'],
  standalone: true,
  imports: [NgxChartsModule],
})
export class LineChartComponent implements OnInit {

  // options
  legend: boolean = true;
  showLabels: boolean = true;
  animations: boolean = true;
  xAxis: boolean = true;
  yAxis: boolean = true;
  showYAxisLabel: boolean = true;
  showXAxisLabel: boolean = true;
  xAxisLabel: string = 'INDIKATOR KESEHATAN INDIVIDU';
  yAxisLabel: string = 'Grafik';
  timeline: boolean = true;
  multi: any[] = [];
  @Input() view: any;
  @Input() legendPosition = LegendPosition.Right;
  colorScheme: any = {
    domain: ['#5AA454', '#E44D25', '#CFC0BB', '#7aa3e5', '#a8385d', '#aae3f5']
  };

  constructor() { }

  ngOnInit() {
    this.generateData();
  }

  generateData() {
    this.multi = [
      {
        "name": "Ryan",
        "series": []
      }
    ];

    // Generating data for each day of January 2024
    for (let day = 1; day <= 31; day++) {
      let formattedDay = day < 10 ? `0${day}` : `${day}`;
      this.multi[0].series.push({
        "name": `${formattedDay}-01-2024`,
        "value": this.getRandomValue(1, 50)
      });
    }
  }

  getRandomValue(min: number, max: number): number {
    return Math.floor(Math.random() * (max - min + 1)) + min;
  }

  onSelect(data: any): void {
    console.log('Item clicked', JSON.parse(JSON.stringify(data)));
  }

  onActivate(data: any): void {
    console.log('Activate', JSON.parse(JSON.stringify(data)));
  }

  onDeactivate(data: any): void {
    console.log('Deactivate', JSON.parse(JSON.stringify(data)));
  }
}
